/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 */

 /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */

#include "include/support.h"
#include "include/command.h"
#include "include/message.h"

class LWCommandSetSpeed: public LWCommand {


LWValue *execute1 (LWContext *context, guint argc, LWValue *args[])
{
	g_return_val_if_fail (argc == 1, NULL);

	context->wizard->setSpeed (args[0]->toInt());
	
	return FALSE;
}	

const gchar *getName () 
{
	return "setspeed";
}	

gchar *getHint ()
{
	return _("Set speed");
}

void checkArgument (guint n, LWValue *value)
{
	(void) n;
	
	if (TRUE == value->toInt() < 0 || TRUE == value->toInt() > 9)
			throw new LWMessage (LW_ERROR_NumberOutOfRange);
}


void checkArgc (guint n)
{
	if (n != 1) 
		throw new LWMessage (LW_ERROR_WrongNumberOfArguments);
}

};

LWSymbol *new_LWCommandSetSpeed()
{
	return new LWCommandSetSpeed();
}
